==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/enumeration/product/OItemCreateProperty.java <==
package eleme.openapi.sdk.api.enumeration.product;

public enum OItemCreateProperty {
    /**
     * 商品名称
     */
    name("name"), 
    
    /**
     * 商品描述
     */
    description("description"), 
    
    /**
     * 图片imageHash
     */
    imageHash("imageHash"), 
    
    /**
     * 标签属性集合
     */
    labels("labels"), 
    
    /**
     * 规格
     */
    specs("specs"), 
    
    /**
     * 售卖时间
     */
    sellingTime("sellingTime"), 
    
    /**
     * 属性
     */
    attributes("attributes"), 
    
    /**
     * 套餐
     */
    packages("packages"), 
    
    /**
     * 后台类目ID
     */
    backCategoryId("backCategoryId"), 
    
    /**
     * 商品最小起购量
     */
    minPurchaseQuantity("minPurchaseQuantity"), 
    
    /**
     * 商品单位
     */
    unit("unit"), 
    
    /**
     * 商品套餐标签
     */
    setMeal("setMeal"), 
    
    /**
     * 原材料
     */
    materials("materials"), 
    
    /**
     * 类目ID
     */
    stdCategoryId("stdCategoryId"), 
    
    /**
     * 后台类目属性
     */
    stdCategoryProperty("stdCategoryProperty"), 
    
    /**
     * 原材料
     */
    mainMaterials("mainMaterials"), 
    
    /**
     * 商品副图片imageHashs
     */
    imageHashs("imageHashs"), 
    
    /**
     * 商品类型
     */
    itemType("itemType"), 
    
    /**
     * 主图联动方式方式
     */
    imageLinkageType("imageLinkageType"), 
    
    /**
     * 商品规格描述
     */
    specAttrs("specAttrs"), 
    
    /**
     * 商品详情图片的hash值
     */
    descPhotoHashes("descPhotoHashes"), 
    
    /**
     * 商品扩展
     */
    itemFeature("itemFeature"), 
    
    /**
     * 商品排序
     */
    rankWeight("rankWeight"), 
    
    /**
     * 商品extend code
     */
    extCode("extCode");
    

    private String productDesc;
    OItemCreateProperty(String productDesc) {
        this.productDesc = productDesc;
    }
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/enumeration/product/OItemCreateProperty.java <==
package eleme.openapi.sdk.api.enumeration.product;

public enum OItemCreateProperty {
    /**
     * 商品名称
     */
    name("name"), 
    
    /**
     * 商品描述
     */
    description("description"), 
    
    /**
     * 图片imageHash
     */
    imageHash("imageHash"), 
    
    /**
     * 标签属性集合
     */
    labels("labels"), 
    
    /**
     * 规格
     */
    specs("specs"), 
    
    /**
     * 售卖时间
     */
    sellingTime("sellingTime"), 
    
    /**
     * 属性
     */
    attributes("attributes"), 
    
    /**
     * 套餐
     */
    packages("packages"), 
    
    /**
     * 后台类目ID
     */
    backCategoryId("backCategoryId"), 
    
    /**
     * 商品最小起购量
     */
    minPurchaseQuantity("minPurchaseQuantity"), 
    
    /**
     * 商品单位
     */
    unit("unit"), 
    
    /**
     * 商品套餐标签
     */
    setMeal("setMeal"), 
    
    /**
     * 原材料
     */
    materials("materials"), 
    
    /**
     * 类目ID
     */
    stdCategoryId("stdCategoryId"), 
    
    /**
     * 后台类目属性
     */
    stdCategoryProperty("stdCategoryProperty"), 
    
    /**
     * 原材料
     */
    mainMaterials("mainMaterials"), 
    
    /**
     * 商品副图片imageHashs
     */
    imageHashs("imageHashs"), 
    
    /**
     * 商品类型
     */
    itemType("itemType"), 
    
    /**
     * 主图联动方式方式
     */
    imageLinkageType("imageLinkageType"), 
    
    /**
     * 商品规格描述
     */
    specAttrs("specAttrs"), 
    
    /**
     * 商品详情图片的hash值
     */
    descPhotoHashes("descPhotoHashes"), 
    
    /**
     * 商品扩展
     */
    itemFeature("itemFeature"), 
    
    /**
     * 商品排序
     */
    rankWeight("rankWeight"), 
    
    /**
     * 商品extend code
     */
    extCode("extCode"), 
    
    /**
     * 商品级别配料
     */
    groupRelations("groupRelations"), 
    
    /**
     * 是否执行item/sku配料操作，默认为false不执行
     */
    pubIngredientGroup("pubIngredientGroup");
    

    private String productDesc;
    OItemCreateProperty(String productDesc) {
        this.productDesc = productDesc;
    }
}
